Improve this doc

# Error: $sce:iequirks
IE8 in quirks mode is unsupported

    Strict Contextual Escaping does not support Internet Explorer version < 9 in quirks mode.  You can fix this by adding the text  to the top of your HTML document.  See http://docs.angularjs.org/api/ng.$sce for more information.

## Description

This error occurs when you are using AngularJS with Strict Contextual Escaping (SCE) mode enabled (the default) on IE8 or lower in quirks mode.

In this mode, IE8 allows one to execute arbitrary javascript by the use of the `expression()` syntax and is not supported. Refer MSDN Blogs > IEBlog > Ending Expressions to learn more about them.

To resolve this error please specify the proper doctype at the top of your main html document:

    <!doctype html>